# Authors and Contributors

**Authors** are people whose contributions significantly shaped
the state of `somesy` at some point in time.

**Additional contributors** are people who contributed non-trivially to this project
in different ways, e.g. by providing smaller fixes and enhancements to the code
and/or documentation.

Of course, this is just a rough overview and categorization.
For a more complete overview of all contributors and contributions,
please inspect the git history of this repository.

## Authors

- Mustafa Soylu (
  [E-Mail](mailto:m.soylu@fz-juelich.de),
  [ORCID](https://orcid.org/0000-0003-2637-0432)
  ): Main developer, maintainer and tester.
- Anton Pirogov (
  [E-Mail](mailto:a.pirogov@fz-juelich.de),
  [ORCID](https://orcid.org/0000-0002-5077-7497)
  ): Concepts, tool development and enhancement, documentation.


## Additional Contributors

- Jens Bröder (
  [E-Mail](mailto:j.broeder@fz-juelich.de),
  [ORCID](https://orcid.org/0000-0001-7939-226X)
  ): Discussions and suggestions concerning metadata standards and usability.
- Volker Hofmann (
  [E-Mail](mailto:v.hofmann@fz-juelich.de),
  [ORCID](https://orcid.org/0000-0002-5149-603X)
  ): Discussions and suggestions concerning tool scope and usability.
- Stefan Sandfeld (
  [E-Mail](mailto:s.sandfeld@fz-juelich.de),
  [ORCID](https://orcid.org/0000-0001-9560-4728)
  )


... maybe **[you](https://materials-data-science-and-informatics.github.io/somesy/latest/contributing)**?
